setwd("~/Dropbox/cross_national")
library(MASS)
library(Zelig)
library(ggplot2)
library(simcf)
library(nlme)
library(effects)
library(lme4)
library(memisc)
library(texreg)

data1 <- read.csv("~/Dropbox/cross_national/including_release_of_info_for_auto_only_analysis.csv")

data1$h_polcon3_lag1S <- scale(data1$h_polcon3_lag1,scale=F)
data1$h_polcon3_lag1S <- as.numeric(data1$h_polcon3_lag1S)
data1$loggdpS <- scale(data1$loggdp,scale=F)
data1$loggdpS <- as.numeric(data1$loggdpS)
data1$pwt_gsg_lag1S <- scale(data1$pwt_gsg_lag1,scale=F)
data1$pwt_gsg_lag1S <- as.numeric(data1$pwt_gsg_lag1S)
data1$wdi_gdpgr_lag1S <- scale(data1$wdi_gdpgr_lag1,scale=F)
data1$wdi_gdpgr_lag1S <- as.numeric(data1$wdi_gdpgr_lag1S)
data1$dpi_yio_lag2S <- scale(data1$dpi_yio_lag2,scale=F)
data1$dpi_yio_lag2S <- as.numeric(data1$dpi_yio_lag2S)
data1$yearS <- scale(data1$year.x,scale=F)
data1$yearS <- as.numeric(data1$yearS)
data1$pwt_gsg_lag1 <- lagpanel(data1$pwt_gsg,data1$cname,data1$year.x,1)
data1$fdi <- data1$wdi_fdi_lag1 / data1$wdi_gnipc_lag1
data1$fdiS <- scale(data1$fdi,scale=F)
data1$fdiS <- as.numeric(data1$fdiS)

options(scipen=120,digits=2)
data2 <- subset(data1,chga_demo=="0. Dictatorship")

form0 <- LJI ~ h_polcon3_lag1 + loggdp + # roi_lag1 + 
		pwt_gsg_lag1 + common + 
		wdi_gdpgr_lag1 + conflict2 + fdi + dpi_yio_lag2 + cname + chga_demo + year.x +
		h_polcon3_lag1 +  transition.next.3years + transition.next.5years + transition.next.8years
data0 <- extractdata(form0,data2,na.rm=T)
#data0 <- subset(data0,chga_demo=="0. Dictatorship")

data0$h_polcon3_lag1S <- scale(data0$h_polcon3_lag1,scale=F)
data0$h_polcon3_lag1S <- as.numeric(data0$h_polcon3_lag1S)
data0$loggdpS <- scale(data0$loggdp,scale=F)
data0$loggdpS <- as.numeric(data0$loggdpS)
data0$pwt_gsg_lag1S <- scale(data0$pwt_gsg_lag1,scale=F)
data0$pwt_gsg_lag1S <- as.numeric(data0$pwt_gsg_lag1S)
data0$wdi_gdpgr_lag1S <- scale(data0$wdi_gdpgr_lag1,scale=F)
data0$wdi_gdpgr_lag1S <- as.numeric(data0$wdi_gdpgr_lag1S)
data0$fdiS <- scale(data0$fdi,scale=F)
data0$fdiS <- as.numeric(data0$fdiS)
data0$dpi_yio_lag2S <- scale(data0$dpi_yio_lag2,scale=F)
data0$dpi_yio_lag2S <- as.numeric(data0$dpi_yio_lag2S)
data0$yearS <- scale(data0$year.x,scale=F)
data0$yearS <- as.numeric(data0$yearS)

form1 <- LJI ~ h_polcon3_lag1S + loggdpS + common + yearS + dpi_yio_lag2S + pwt_gsg_lag1S +
				fdiS + conflict2 + (1|cname) 		
				
res.hlm <- lmer(form1,data0,REML=FALSE)
res.fe <- lm(LJI ~ h_polcon3_lag1S + loggdpS + common + yearS + dpi_yio_lag2S + pwt_gsg_lag1S +
				fdiS + conflict2 +
				cname ,data0)

model2 <- LJI ~ h_polcon3_lag1 +
				common + loggdp + cname + year.x + dpi_yio_lag2
chdata <- extractdata(model2,data2,na.rm=T)
chdata$h_polcon3_lag1S <- scale(chdata$h_polcon3_lag1,scale=F)
chdata$h_polcon3_lag1S <- as.numeric(chdata$h_polcon3_lag1S)
chdata$loggdpS <- scale(chdata$loggdp,scale=F)
chdata$loggdpS <- as.numeric(chdata$loggdpS)
chdata$yearS <- scale(chdata$year.x,scale=F)
chdata$yearS <- as.numeric(chdata$yearS)
chdata$dpi_yio_lag2S <- scale(chdata$dpi_yio_lag2,scale=F)
chdata$dpi_yio_lag2S <- as.numeric(chdata$dpi_yio_lag2S)

res.hlm.ch <- lmer(LJI ~ h_polcon3_lag1S + loggdpS + common + yearS + dpi_yio_lag2S + (1|cname),
				chdata,REML=FALSE)	
res.fe.ch <- lm(LJI ~ h_polcon3_lag1S + loggdpS + common + yearS + dpi_yio_lag2S + 
				cname,chdata)		

model2 <- LJI ~ h_polcon3_lag1 +
				common + loggdp + cname + year.x
rdata <- extractdata(model2,data2,na.rm=T)
rdata$h_polcon3_lag1S <- scale(rdata$h_polcon3_lag1,scale=F)
rdata$h_polcon3_lag1S <- as.numeric(rdata$h_polcon3_lag1S)
rdata$loggdpS <- scale(rdata$loggdp,scale=F)
rdata$loggdpS <- as.numeric(rdata$loggdpS)
rdata$yearS <- scale(rdata$year.x,scale=F)
rdata$yearS <- as.numeric(rdata$yearS)

res.hlm.r <- lmer(LJI ~ h_polcon3_lag1S + loggdpS + 
				common + yearS + (1|cname),rdata,REML=FALSE)	
res.fe.r <- lm(LJI ~ h_polcon3_lag1S + loggdpS + common + yearS +
				cname,rdata)		

texreg(list(res.hlm, res.fe, res.hlm.ch, res.fe.ch, res.hlm.r, res.fe.r),stars=c(0.001,0.01,0.05),digits=2,booktabs=TRUE,dcolumn=TRUE)
# And there we have table 1
## AICc by hand
options(digits=7)
AICc(res.hlm) 
AICc(res.fe) 
AICc(res.hlm.ch) 
AICc(res.fe.ch) 
AICc(res.hlm.r) 
AICc(res.fe.r) 
options(digits=2)


##
## Figure 1 code
##

library(extrafont)
loadfonts()

# Model 1	
polcon_range <- seq(min(data0$h_polcon3_lag1),max(data0$h_polcon3_lag1),0.01)
Polcon <- mean(data0$h_polcon3_lag1S)
Loggdp <- mean(data0$loggdpS)
Conflict <- mean(data0$conflict2)
Common <- mean(data0$common)
Gsg <- 	  mean(data0$pwt_gsg_lag1S)
Yio <-	  mean(data0$dpi_yio_lag2S)
FDI <-	  mean(data0$fdiS)
Year <- mean(data0$yearS)
	
beta <- fixef(res.hlm)
covvar <- vcov(res.hlm)
x <- data.frame(1,polcon_range,Loggdp,Common,Year,Yio,Gsg,FDI,Conflict)

beta.sim <- mvrnorm(10000,beta,covvar)
xb <- as.matrix(x) %*% t(beta.sim)

confinf <- apply(xb,1,quantile,probs = c(.05,.5,.95))
dat <- data.frame(x = polcon_range, lower = confinf[1,], 
	middle = confinf[2,], upper = confinf[3,])

# model 3
polcon_range <- seq(min(chdata$h_polcon3_lag1),max(chdata$h_polcon3_lag1),0.01)
Polcon <- mean(chdata$h_polcon3_lag1S)
Cnames <- unique(chdata$cname)
Loggdp <- mean(chdata$loggdpS)
Common <- mean(chdata$common)
YIO <- mean(chdata$dpi_yio_lag2S)
YEAR <- mean(chdata$yearS)

beta <- fixef(res.hlm.ch)
covvar <- vcov(res.hlm.ch)
x <- data.frame(1,polcon_range,Loggdp,Common,YEAR,YIO)

beta.sim <- mvrnorm(10000,beta,covvar)
xb <- as.matrix(x) %*% t(beta.sim)

confinf <- apply(xb,1,quantile,probs = c(.05,.5,.95))
dat2 <- data.frame(x2 = polcon_range, lower2 = confinf[1,], 
	middle2 = confinf[2,], upper2 = confinf[3,])

# model 5
polcon_range <- seq(min(rdata$h_polcon3_lag1),max(rdata$h_polcon3_lag1),0.01)
Polcon <- mean(rdata$h_polcon3_lag1S)
Cnames <- unique(rdata$cname)
Loggdp <- mean(rdata$loggdpS)
Common <- mean(rdata$common)
YEAR <- mean(rdata$yearS)

beta <- fixef(res.hlm.r)
covvar <- vcov(res.hlm.r)
x <- data.frame(1,polcon_range,Loggdp,Common,YEAR)

beta.sim <- mvrnorm(10000,beta,covvar)
xb <- as.matrix(x) %*% t(beta.sim)

confinf <- apply(xb,1,quantile,probs = c(.05,.5,.95))
dat3 <- data.frame(x3 = polcon_range, lower3 = confinf[1,], 
	middle3 = confinf[2,], upper3 = confinf[3,])
dat4 <- cbind(dat,dat2,dat3)

plot <- ggplot(dat4, aes(x = x))
plot <- plot + geom_ribbon(aes(ymin = lower,ymax=upper), alpha = 0.2)
plot <- plot + geom_line(aes(y = middle), linetype = 1,size=1.5)
plot <- plot + geom_line(aes(y= middle2),linetype = 2, size=2)
plot <- plot + geom_ribbon(aes(ymin = lower2, ymax=upper2),alpha = 0.2)
plot <- plot + geom_line(aes(y= middle3),linetype = 3, size=2)
plot <- plot + geom_ribbon(aes(ymin = lower3, ymax=upper3),alpha = 0.2)
plot
plot <- plot + scale_x_continuous('Political competition')
plot <- plot + scale_y_continuous('E(Judicial independence)',limits=c(0.15,0.45))
plot <- plot + annotate("segment",x=0.3, xend=0.5, y= 0.22,yend=0.22,size=1.5)
plot <- plot + annotate("text",x=0.6,y=0.22,label="Model 1",size=6.5,family="Times")
plot <- plot + annotate("segment",x=0.3, xend=0.5, y= 0.19,yend=0.19,size=1.5,linetype=2)
plot <- plot + annotate("text",x=0.6,y=0.19,label="Model 3",size=6.5,family="Times")
plot <- plot + annotate("segment",x=0.3, xend=0.5, y= 0.16,yend=0.16,size=1.5,linetype=3)
plot <- plot + annotate("text",x=0.6,y=0.16,label="Model 5",size=6.5,family="Times")
plot

#plot <- plot + theme(title="")
#plot <- plot + theme(axis.title.y=theme_text(hjust=2))
plot <- plot + theme_bw()
plot <- plot + theme(plot.title=element_text(size=25,family="Times"))
plot <- plot + theme(axis.title.y = element_text(size=20,angle=90,family="Times"),
          axis.text.y=element_text(size=16,family="Times"))
plot <- plot + theme(axis.title.x = element_text(size=20,family="Times"),
          axis.text.x  = element_text(size=16,family="Times"))
plot


ggsave("ranef_plot_polcomp.pdf",plot,width=5,height=5)
ggsave("EJPR figure 1 plot a.tiff",plot,width=5,height=5)

## FIXED EFFECTS MODELS

# Model 2
polcon_range <- seq(min(data0$h_polcon3_lag1),max(data0$h_polcon3_lag1),0.01)
Polcon <- mean(data0$h_polcon3_lag1S)
Loggdp <- mean(data0$loggdpS)
Conflict <- mean(data0$conflict2)
Common <- mean(data0$common)
Gsg <- 	  mean(data0$pwt_gsg_lag1S)
Yio <-	  mean(data0$dpi_yio_lag2S)
FDI <-	  mean(data0$fdiS)
Year <- mean(data0$yearS)
		
beta <- coef(res.fe)[1:9]
covvar <- vcov(res.fe)[1:9,1:9]
x <- data.frame(1,polcon_range,Loggdp,Common,Year,Yio,Gsg,FDI,Conflict)

beta.sim <- mvrnorm(10000,beta,covvar)
xb <- as.matrix(x) %*% t(beta.sim)

confinf <- apply(xb,1,quantile,probs = c(.05,.5,.95))
dat <- data.frame(x = polcon_range, lower = confinf[1,], 
	middle = confinf[2,], upper = confinf[3,])
	
# model 4
polcon_range <- seq(min(chdata$h_polcon3_lag1),max(chdata$h_polcon3_lag1),0.01)
Polcon <- mean(chdata$h_polcon3_lag1S)
Cnames <- unique(chdata$cname)
Loggdp <- mean(chdata$loggdpS)
Common <- mean(chdata$common)
YIO <- mean(chdata$dpi_yio_lag2S)
YEAR <- mean(chdata$yearS)

beta <- coef(res.fe.ch)[1:6]
covvar <- vcov(res.fe.ch)[1:6,1:6]
x <- data.frame(1,polcon_range,Loggdp,Common,YEAR,YIO)

beta.sim <- mvrnorm(10000,beta,covvar)
xb <- as.matrix(x) %*% t(beta.sim)

confinf <- apply(xb,1,quantile,probs = c(.05,.5,.95))
dat2 <- data.frame(x2 = polcon_range, lower2 = confinf[1,], 
	middle2 = confinf[2,], upper2 = confinf[3,])

# model 6
polcon_range <- seq(min(rdata$h_polcon3_lag1),max(rdata$h_polcon3_lag1),0.01)
Polcon <- mean(rdata$h_polcon3_lag1S)
Cnames <- unique(rdata$cname)
Loggdp <- mean(rdata$loggdpS)
Common <- mean(rdata$common)
YEAR <- mean(rdata$yearS)

beta <- coef(res.fe.r)[1:5]
covvar <- vcov(res.fe.r)[1:5,1:5]

x <- data.frame(1,polcon_range,Loggdp,Common,YEAR)

beta.sim <- mvrnorm(10000,beta,covvar)
xb <- as.matrix(x) %*% t(beta.sim)

confinf <- apply(xb,1,quantile,probs = c(.05,.5,.95))
dat3 <- data.frame(x3 = polcon_range, lower3 = confinf[1,], 
	middle3 = confinf[2,], upper3 = confinf[3,])
dat4 <- cbind(dat,dat2,dat3)

plot <- ggplot(dat4, aes(x = x))
plot <- plot + geom_ribbon(aes(ymin = lower,ymax=upper), alpha = 0.2)
plot <- plot + geom_line(aes(y = middle), linetype = 1,size=1.5)
plot <- plot + geom_line(aes(y= middle2),linetype = 2, size=2)
plot <- plot + geom_ribbon(aes(ymin = lower2, ymax=upper2),alpha = 0.2)
plot <- plot + geom_line(aes(y= middle3),linetype = 3, size=2)
plot <- plot + geom_ribbon(aes(ymin = lower3, ymax=upper3),alpha = 0.2)
plot
plot <- plot + scale_x_continuous('Political competition')
plot <- plot + scale_y_continuous('',limits=c(0.15,0.45))
plot <- plot + annotate("segment",x=0.05, xend=0.25, y= 0.43,yend=0.43,size=1.5)
plot <- plot + annotate("text",x=0.35,y=0.43,label="Model 2",size=6.5,family="Times")
plot <- plot + annotate("segment",x=0.05, xend=0.25, y= 0.40,yend=0.40,size=1.5,linetype=2)
plot <- plot + annotate("text",x=0.35,y=0.4,label="Model 4",size=6.5,family="Times")
plot <- plot + annotate("segment",x=0.05, xend=0.25, y= 0.37,yend=0.37,size=1.5,linetype=3)
plot <- plot + annotate("text",x=0.35,y=0.37,label="Model 6",size=6.5,family="Times")
plot
plot <- plot + theme_bw()
plot <- plot + theme(plot.title=element_text(size=25,family="Times"))
plot <- plot + theme(axis.title.y = element_text(size=20,angle=90,family="Times"),
          axis.text.y=element_text(size=16,family="Times"))
plot <- plot + theme(axis.title.x = element_text(size=20,family="Times"),
          axis.text.x  = element_text(size=16,family="Times"))
plot

ggsave("fixef_plot_polcomp.pdf",plot,width=5,height=5)
ggsave("EJPR figure 1 plot b.tiff",plot,width=5,height=5)


##
## TABLE 2 
##
## REMOVING YEARS IMMEDIATELY BEFORE A REGIME TRANSITION

form1 <- LJI ~ h_polcon3_lag1S + loggdpS + common + yearS + dpi_yio_lag2S + pwt_gsg_lag1S +
				fdiS + conflict2 + (1|cname) 			
				
res.hlm.t3 <- lmer(form1,data0,REML=FALSE,subset=transition.next.3years==0)
res.hlm.t5 <- lmer(form1,data0,REML=FALSE,subset=transition.next.5years==0)
res.hlm.t8 <- lmer(form1,data0,REML=FALSE,subset=transition.next.8years==0)

res.fe.t3 <- lm(LJI ~ h_polcon3_lag1S + loggdpS + common + yearS + dpi_yio_lag2S + pwt_gsg_lag1S +
				fdiS + conflict2 + cname,data0,subset=transition.next.3years==0)
res.fe.t5 <- lm(LJI ~ h_polcon3_lag1S + loggdpS + common + yearS + dpi_yio_lag2S + pwt_gsg_lag1S +
				fdiS + conflict2 + cname,data0,subset=transition.next.5years==0)
res.fe.t8 <- lm(LJI ~ h_polcon3_lag1S + loggdpS + common + yearS + dpi_yio_lag2S + pwt_gsg_lag1S +
				fdiS + conflict2 + cname,data0,subset=transition.next.8years==0)
				

mtableT1 <- mtable("Model $1_{2}$" = res.hlm.t3, "Model $1_{4}$" = res.hlm.t5, 
				   "Model $1_{7}$" = res.hlm.t8,
				   "Model $2_{2}$" = res.fe.t3, "Model $2_{4}$" = res.fe.t5, 
				   "Model $2_{7}$" = res.fe.t8,
					summary.stats=c("AIC","N"))

mtableT3 <- (mtableT3 <- relabel(mtableT1,
	"(Intercept)"="Intercept",
	"h_polcon3_lag1S" = "Political competition",
	"loggdpS" = "log(GDP/capita)",
	"common" = "Common law heritage",
	"yearS" = "Year",
	"dpi_yio_lag2S" = "Years in office",
	"pwt_gsg_lag1S" = "Government share of GDP",
	"fdiS" = "Foreign direct investment",
	"conflict2" = "Conflict",
	"Ranef - cname" = "Random effect: country",
	"Ranef - year.x" = "Random effect: year",		
	"Ranef - Residual" = "Random effect: residual",
))
mtableT3
toLatex(mtableT3,bottomrule="\\bottomrule \\bottomrule",toprule="\\toprule \\toprule")

texreg(list(res.hlm.t3, res.hlm.t5, res.hlm.t8, res.fe.t3, res.fe.t5, res.fe.t8),stars=c(0.001,0.01,0.05),digits=2,booktabs=TRUE,dcolumn=TRUE)
AICc(res.hlm.t3) #etc


##
## TABLE 3 
##

dataF <- read.csv("~/Documents/Washington/Diss/Chapter_2/fates/fates data feb 2012.csv")
dataF <- subset(dataF,exit!=2)
dataF <- subset(dataF,exit!=2.1)
dataF <- subset(dataF,exit!=2.2)
dataF <- subset(dataF,exit!=4)
dataF <- subset(dataF,exit!=-888.0)

dataF$SLJI_lag1 <- scale(dataF$LJI_lag1,scale=F)
dataF$gle_log <- log(dataF$gle_rgdp)
dataF$Sloggdp <- scale(dataF$gle_log,scale=F)

dataF1 <- subset(dataF,chga_demo=="0. Dictatorship")
dataF2 <- subset(dataF,chga_demo=="1. Democracy")

res.model1 <- glm(ptfateD ~ SLJI_lag1 + Sloggdp  + chga_demo,dataF,family=binomial)
res.model2 <- glm(ptfateD ~ SLJI_lag1 + Sloggdp ,dataF2,family=binomial,subset=exit==1)
res.model3 <- glm(ptfateD ~ SLJI_lag1 + Sloggdp ,dataF1,family=binomial,subset=exit==1)
res.model4 <- glm(ptfateD ~ SLJI_lag1 + Sloggdp ,dataF1,family=binomial,subset=exit==3)
res.model5 <- glm(ptfateD ~ SLJI_lag1 + Sloggdp ,dataF2,family=binomial,subset=exit==3)
 		
mtable(res.model2,res.model3,res.model4,res.model5)
texreg(list(res.model1, res.model2, res.model3,res.model4),
			custom.coef.names=c("Intercept","Judicial independence","log(GDP/capita","Democracy"),
			stars=c(0.001,0.01,0.05,0.1),digits=2,symbol="\\dagger",booktabs=TRUE,dcolumn=TRUE)
AICc(res.model1) 
AICc(res.model2) 
AICc(res.model3) 
AICc(res.model4) 


##
## 
## SUPPLEMENTAL INFORMATION CODE
##
## 

## Cross validation

form1 <- LJI ~ h_polcon3_lag1S + loggdpS + common + yearS + dpi_yio_lag2S + pwt_gsg_lag1S +
				fdiS + conflict2 + (1|cname) 		
res.hlm <- lmer(form1,data0,REML=FALSE)
res.fe <- lm(LJI ~ h_polcon3_lag1S + loggdpS + common + yearS + dpi_yio_lag2S + pwt_gsg_lag1S +
				fdiS + conflict2 + cname,data0)

res.hlm.ch <- lmer(LJI ~ h_polcon3_lag1S + loggdpS + common + yearS + dpi_yio_lag2S + (1|cname),
				chdata,REML=FALSE)	
res.fe.ch <- lm(LJI ~ h_polcon3_lag1S + loggdpS + common + yearS + dpi_yio_lag2S + 
				cname,chdata)	
				
res.hlm.r <- lmer(LJI ~ h_polcon3_lag1S + loggdpS + 
				common + yearS + (1|cname),rdata,REML=FALSE)	
res.fe.r <- lm(LJI ~ h_polcon3_lag1S + loggdpS + common + yearS +
				cname,rdata)							
				
				   
# Unfortunately due to sampling issues with the full data set it's impossible to get each level of the cname factor (i.e. one of each country, as Cape Verde has only 1 obs and some have <5) into each subset, meaning you can't run the FE model
set.seed(3)
infitset <- sample(rownames(rdata),size=dim(rdata)[[1]]/2) 
#assign rows to a fit set (fit being the set we "train" our model on)
totalset <- rownames(rdata) #make a total set
intestset <- setdiff(totalset,infitset) #differentiate
fitset <- rdata[infitset,] #make the fit set
testset <- rdata[intestset,] #make the test set (to test the coef on)

model2 <- LJI ~ h_polcon3_lag1S +
				common + loggdpS + yearS
nlme.fit <- lme(model2,
				random = ~ 1 | cname,
				data=fitset)		
				
preds <- predict(nlme.fit,testset) #LME takes predictions, which will be crucial for cross-validation, so let's use it instead of the (newer, "better") lmer (which would take the command fitted()... they do the same thing)
rmse <- function(obs,pred) sqrt(mean((obs-pred)^2)) #function to get RMSE
oos.RMSE <- rmse(testset$LJI,preds)
oos.RMSE
rmse(fitset$LJI,fitted(nlme.fit))

# fe.fit <- lm(LJI ~ h_polcon3_lag1S + loggdpS + common + 
				# yearS + cname,data=fitset)			
# fe.preds <- predict(fe.fit,testset) 

# oos.RMSE <- rmse(testset$LJI,fe.preds)
# oos.RMSE
# rmse(fitset$LJI,fitted(fe.fit))



fitset$preds <- predict(as.vector(nlme.fit))
testset$preds <- preds
dim(testset)
length(fitset$preds)

p <- ggplot(fitset,aes(preds,LJI))
p <- p + geom_point(alpha=I(1/3),size=2.5)
#p <- p + theme(title="In-sample fit")
p <- p + theme_bw()
p <- p + theme(plot.title=element_text(size=25))
p <- p + theme(axis.title.y = element_text(size=18,angle=90),
          axis.text.y=element_text(size=14))
p <- p + theme(axis.title.x = element_text(size=18),
          axis.text.x  = element_text(size=14))
p <- p + scale_x_continuous('',limits=c(-0.05,1.05)) + scale_y_continuous('Actual values',limits=c(0,1))    
p <- p + theme(legend.title=element_text(colour="black",size=18,family="Times"))      
p <- p + theme(legend.title=element_text(colour="black",size=16,family="Times")) + theme(legend.position=c(1,1))  + theme(legend.justification=c(1,1))
p <- p + geom_abline(intercept=0,slope=1,colour="black")
p <- p + geom_abline(intercept=rmse(fitset$LJI,fitted(nlme.fit))*1.96,slope=1,colour="black",lty=2)
p <- p + geom_abline(intercept=rmse(fitset$LJI,fitted(nlme.fit))*-1.96,slope=1,colour="black",lty=2)
p <- p + theme(text=element_text(family="Times"))         
p
ggsave("model5_in_sample_crossval.pdf",p,width=5,height=5)



p <- ggplot(testset,aes(preds,LJI))
p <- p + geom_point(alpha=I(1/3),size=2.5)
#p <- p + theme(title="In-sample fit")
p <- p + theme_bw()
p <- p + theme(plot.title=element_text(size=25))
p <- p + theme(axis.title.y = element_text(size=18,angle=90),
          axis.text.y=element_text(size=14))
p <- p + theme(axis.title.x = element_text(size=18),
          axis.text.x  = element_text(size=14))
p <- p + scale_x_continuous('Predicted values',limits=c(-0.05,1.05)) + scale_y_continuous('',limits=c(0,1))    
p <- p + theme(legend.title=element_text(colour="black",size=18))      
p <- p + theme(legend.title=element_text(colour="black",size=16)) + theme(legend.position=c(1,1))  + theme(legend.justification=c(1,1))
p <- p + geom_abline(intercept=0,slope=1,colour="black")
p <- p + geom_abline(intercept=rmse(testset$LJI,preds)*1.96,slope=1,colour="black",lty=2)
p <- p + geom_abline(intercept=rmse(testset$LJI,preds)*-1.96,slope=1,colour="black",lty=2)
p
p <- p + theme(text=element_text(family="Times"))         
p
ggsave("model5_out_sample_crossval.pdf",p,width=5,height=5)


fitset$fe.preds <- predict(as.vector(fe.fit))
testset$fe.preds <- fe.preds

p <- ggplot(fitset,aes(fe.preds,LJI))
p <- p + geom_point(alpha=I(1/3),size=2.5)
#p <- p + theme(title="In-sample fit")
p <- p + theme_bw()
p <- p + theme(plot.title=element_text(size=25))
p <- p + theme(axis.title.y = element_text(size=18,angle=90),
          axis.text.y=element_text(size=14))
p <- p + theme(axis.title.x = element_text(size=18),
          axis.text.x  = element_text(size=14))
p <- p + scale_x_continuous('Predicted values',limits=c(-0.05,1.05)) + scale_y_continuous('',limits=c(0,1))    
p <- p + theme(legend.title=element_text(colour="black",size=18))      
p <- p + theme(legend.title=element_text(colour="black",size=16)) + theme(legend.position=c(1,1))  + theme(legend.justification=c(1,1))
p <- p + geom_abline(intercept=0,slope=1,colour="black")
p <- p + geom_abline(intercept=rmse(fitset$LJI,fitted(fe.fit))*1.96,slope=1,colour="black",lty=2)
p <- p + geom_abline(intercept=rmse(fitset$LJI,fitted(fe.fit))*-1.96,slope=1,colour="black",lty=2)
p
p <- p + theme(text=element_text(family="Times"))         
p
ggsave("model6_in_sample_crossval.pdf",p,width=5,height=5)

p <- ggplot(testset,aes(fe.preds,LJI))
p <- p + geom_point(alpha=I(1/3),size=2.5)
#p <- p + theme(title="In-sample fit")
p <- p + theme_bw()
p <- p + theme(plot.title=element_text(size=25))
p <- p + theme(axis.title.y = element_text(size=18,angle=90),
          axis.text.y=element_text(size=14))
p <- p + theme(axis.title.x = element_text(size=18),
          axis.text.x  = element_text(size=14))
p <- p + scale_x_continuous('',limits=c(-0.05,1.05)) + scale_y_continuous('Actual values',limits=c(0,1))    
p <- p + theme(legend.title=element_text(colour="black",size=18))      
p <- p + theme(legend.title=element_text(colour="black",size=16)) + theme(legend.position=c(1,1))  + theme(legend.justification=c(1,1))
p <- p + geom_abline(intercept=0,slope=1,colour="black")
p <- p + geom_abline(intercept=rmse(testset$LJI,fe.preds)*1.96,slope=1,colour="black",lty=2)
p <- p + geom_abline(intercept=rmse(testset$LJI,fe.preds)*-1.96,slope=1,colour="black",lty=2)
p
p <- p + theme(text=element_text(family="Times"))         
p
ggsave("model6_out_sample_crossval.pdf",p,width=5,height=5)



## FREEDOM HOUSE MEASURE

dataQ <- read.csv("~/Dropbox/cross_national/including_release_of_info_for_auto_only_analysis.csv")
dataQ$pwt_gsg_lag1 <- lagpanel(dataQ$pwt_gsg,dataQ$cname,dataQ$year.x,1)

dataQ$fdi <- dataQ$wdi_fdi_lag1 / dataQ$wdi_gnipc_lag1
dataQ$fdiS <- scale(dataQ$fdi,scale=F)
dataQ$fdiS <- as.numeric(dataQ$fdiS)


formFH <- LJI ~ h_polcon3_lag1 + loggdp + + pwt_gsg_lag1 + common + 
		conflict2 + fdi + dpi_yio_lag2 + cname + fh_democ + year.x + fh_tri  
#		+ transition.next.3years.FHPR +  transition.next.5years.FHPR +
#		transition.next.8years.FHPR 
dataFH <- extractdata(formFH,dataQ,na.rm=T)
dataFH <- subset(dataFH,fh_democ=="non-democ")		

dataFH$h_polcon3_lag1S <- scale(dataFH$h_polcon3_lag1,scale=F)
dataFH$h_polcon3_lag1S <- as.numeric(dataFH$h_polcon3_lag1S)
dataFH$loggdpS <- scale(dataFH$loggdp,scale=F)
dataFH$loggdpS <- as.numeric(dataFH$loggdpS)
dataFH$pwt_gsg_lag1S <- scale(dataFH$pwt_gsg_lag1,scale=F)
dataFH$pwt_gsg_lag1S <- as.numeric(dataFH$pwt_gsg_lag1S)
dataFH$fdiS <- scale(dataFH$fdi,scale=F)
dataFH$fdiS <- as.numeric(dataFH$fdiS)
dataFH$dpi_yio_lag2S <- scale(dataFH$dpi_yio_lag2,scale=F)
dataFH$dpi_yio_lag2S <- as.numeric(dataFH$dpi_yio_lag2S)
dataFH$yearS <- scale(dataFH$year.x,scale=F)
dataFH$yearS <- as.numeric(dataFH$yearS)
#dataFH$LJIlogit <- logit(dataFH$LJI)
				
form1 <- LJI ~ h_polcon3_lag1S + loggdpS + common + yearS + dpi_yio_lag2S + pwt_gsg_lag1S +
				fdiS + conflict2 + yearS + (1|cname) 		
				
res.hlmFH <- lmer(form1,dataFH,REML=FALSE)
res.feFH <- lm(LJI ~ h_polcon3_lag1S + loggdpS + common + yearS + dpi_yio_lag2S + pwt_gsg_lag1S +
				fdiS + conflict2 + cname,
				dataFH)		
# resL.hlmFH <- lmer(LJIlogit ~ h_polcon3_lag1S + loggdpS+ common + conflict2 + pwt_gsg_lag1S +
				# dpi_yio_lag2S + fdiS + 
				# (1|cname) + (1|year.x),dataFH,REML=FALSE)
# resL.feFH <- lm(LJIlogit ~ h_polcon3_lag1S + loggdpS+ common + conflict2 + pwt_gsg_lag1S +
				# dpi_yio_lag2S + fdiS + cname + as.factor(year.x),
				# dataFH)		
				
model2 <- LJI ~ h_polcon3_lag1 + loggdp +
				common + loggdp + cname + year.x + fh_democ + dpi_yio_lag2
fhdataQ <- extractdata(model2,dataQ,na.rm=T)
fhdataQ <- subset(fhdataQ,fh_democ=="non-democ")

fhdataQ$h_polcon3_lag1S <- scale(fhdataQ$h_polcon3_lag1,scale=F)
fhdataQ$h_polcon3_lag1S <- as.numeric(fhdataQ$h_polcon3_lag1S)
fhdataQ$loggdpS <- scale(fhdataQ$loggdp,scale=F)
fhdataQ$loggdpS <- as.numeric(fhdataQ$loggdpS)
fhdataQ$LJIlogit <- logit(fhdataQ$LJI)
fhdataQ$dpi_yio_lag2S <- scale(fhdataQ$dpi_yio_lag2,scale=F)
fhdataQ$dpi_yio_lag2S <- as.numeric(fhdataQ$dpi_yio_lag2S)
fhdataQ$yearS <- scale(fhdataQ$year.x,scale=F)
fhdataQ$yearS <- as.numeric(fhdataQ$yearS)

res.fe.fh2 <- lm(LJI ~ h_polcon3_lag1S + loggdpS + common + yearS + dpi_yio_lag2S +
				cname,fhdataQ)				   
res.hlm.fh2 <- lmer(LJI ~ h_polcon3_lag1S + loggdpS + common + yearS + dpi_yio_lag2S +
				 (1|cname),fhdataQ,REML=FALSE)

model3 <- LJI ~ h_polcon3_lag1 + loggdp +
				common + loggdp + cname + year.x + fh_democ
fhdata3 <- extractdata(model3,dataQ,na.rm=T)
fhdata3 <- subset(fhdata3,fh_democ=="non-democ")

fhdata3$h_polcon3_lag1S <- scale(fhdata3$h_polcon3_lag1,scale=F)
fhdata3$h_polcon3_lag1S <- as.numeric(fhdata3$h_polcon3_lag1S)
fhdata3$loggdpS <- scale(fhdata3$loggdp,scale=F)
fhdata3$loggdpS <- as.numeric(fhdata3$loggdpS)
fhdata3$yearS <- scale(fhdata3$year.x,scale=F)
fhdata3$yearS <- as.numeric(fhdata3$yearS)

res.fe.fh3 <- lm(LJI ~ h_polcon3_lag1S + loggdpS + common + yearS  +
				cname,fhdata3)				   
res.hlm.fh3 <- lmer(LJI ~ h_polcon3_lag1S + loggdpS + common + yearS  +
				 (1|cname),fhdata3,REML=FALSE)


texreg(list(res.hlmFH,res.feFH,res.hlm.fh2,res.fe.fh2,res.hlm.fh3,res.fe.fh3),stars=c(0.001,0.01,0.05),digits=2,booktabs=TRUE,dcolumn=TRUE)

mtable123 <- mtable("Model 1a" = res.hlmFH,"Model 2a" = res.feFH,"Model 3a" = res.hlm.fh2, "Model 4a" =
					res.fe.fh2,"Model 5a" = res.hlm.fh3, "Model 6a" = res.fe.fh3,
					summary.stats=c("AIC","N"))
mtable124 <- (mtable123 <- relabel(mtable123,
	"(Intercept)"="Intercept",
	"h_polcon3_lag1S" = "Political competition",
	"loggdpS" = "log(GDP/capita)",
	"common" = "Common law heritage",
	"yearS" = "Year",
	"pwt_gsg_lag1S" = "Government share of GDP",
	"roi_lag1S" = "Bureaucratic quality",
	"Ranef - cname" = "Random effect: country",
	"Ranef - year.x" = "Random effect: year",
	"Ranef - Residual" = "Random effect: residual",
	"wdi_gdpgr_lag1S" = "Economic growth",
	"conflict2" = "Conflict",
	"fdiS" = "Foreign direct investment",
	"dpi_yio_lag2S" = "Years in office"
)
)
mtable124
toLatex(mtable124,bottomrule="\\bottomrule \\bottomrule",toprule="\\toprule \\toprule")
options(digits=6)
AICc(res.hlmFH)
AICc(res.feFH)
AICc(res.hlm.fh2)
AICc(res.fe.fh2)
AICc(res.hlm.fh3)
AICc(res.fe.fh3)
options(digits=2)


#
# Excluding "fullest" autocracies

dataP <- subset(data1,chga_demo=="0. Dictatorship")

formP <- LJI ~ h_polcon3_lag1 + loggdp + # roi_lag1 + 
		pwt_gsg_lag1 + common + 
		wdi_gdpgr_lag1 + conflict2 + fdi + dpi_yio_lag2 + 
		cname + chga_demo + year.x +
		h_polcon3_lag1 +  transition.next.3years + 
		transition.next.5years + transition.next.8years + p_polity2
dataP <- extractdata(formP,dataP,na.rm=TRUE)	

dataP$h_polcon3_lag1S <- scale(dataP$h_polcon3_lag1,scale=FALSE)
dataP$h_polcon3_lag1S <- as.numeric(dataP$h_polcon3_lag1S)
dataP$loggdpS <- scale(dataP$loggdp,scale=F)
dataP$loggdpS <- as.numeric(dataP$loggdpS)
dataP$pwt_gsg_lag1S <- scale(dataP$pwt_gsg_lag1,scale=F)
dataP$pwt_gsg_lag1S <- as.numeric(dataP$pwt_gsg_lag1S)
dataP$wdi_gdpgr_lag1S <- scale(dataP$wdi_gdpgr_lag1,scale=F)
dataP$wdi_gdpgr_lag1S <- as.numeric(dataP$wdi_gdpgr_lag1S)
dataP$fdiS <- scale(dataP$fdi,scale=F)
dataP$fdiS <- as.numeric(dataP$fdiS)
dataP$dpi_yio_lag2S <- scale(dataP$dpi_yio_lag2,scale=F)
dataP$dpi_yio_lag2S <- as.numeric(dataP$dpi_yio_lag2S)
dataP$yearS <- scale(dataP$year.x,scale=F)
dataP$yearS <- as.numeric(dataP$yearS)

formP <- LJI ~ h_polcon3_lag1 + loggdpS + common + yearS + 
				dpi_yio_lag2S + pwt_gsg_lag1S +
				fdiS + conflict2 + (1|cname) 	
res.hlmP <- lmer(formP,dataP,REML=FALSE,subset=p_polity2 < -5)
res.feP <- lm(LJI ~ h_polcon3_lag1 + loggdpS + common + yearS + 
				dpi_yio_lag2S + pwt_gsg_lag1S +
				fdiS + conflict2 + cname ,dataP,subset=p_polity2 < -5)
summary(res.feP)



dataP2 <- subset(data1,chga_demo=="0. Dictatorship")
formP2 <- LJI ~ h_polcon3_lag1 + loggdp + # roi_lag1 + 
		pwt_gsg_lag1 + common + 
		wdi_gdpgr_lag1 + conflict2 + fdi + dpi_yio_lag2 + 
		cname + chga_demo + year.x +
		h_polcon3_lag1 +  transition.next.3years + 
		transition.next.5years + transition.next.8years + ht_regtype1
dataP2 <- extractdata(formP2,dataP2,na.rm=TRUE)	
dataP2 <- subset(dataP2,ht_regtype1!="1. Monarchy")		
dataP2 <- subset(dataP2,ht_regtype1!="9. No-party")	
dataP3 <- subset(dataP2,ht_regtype1!="3. One-party")		

dataP3$loggdpS <- scale(dataP3$loggdp,scale=F)
dataP3$loggdpS <- as.numeric(dataP3$loggdpS)
dataP3$pwt_gsg_lag1S <- scale(dataP3$pwt_gsg_lag1,scale=F)
dataP3$pwt_gsg_lag1S <- as.numeric(dataP3$pwt_gsg_lag1S)
dataP3$wdi_gdpgr_lag1S <- scale(dataP3$wdi_gdpgr_lag1,scale=F)
dataP3$wdi_gdpgr_lag1S <- as.numeric(dataP3$wdi_gdpgr_lag1S)
dataP3$fdiS <- scale(dataP3$fdi,scale=F)
dataP3$fdiS <- as.numeric(dataP3$fdiS)
dataP3$dpi_yio_lag2S <- scale(dataP3$dpi_yio_lag2,scale=F)
dataP3$dpi_yio_lag2S <- as.numeric(dataP3$dpi_yio_lag2S)
dataP3$yearS <- scale(dataP3$year.x,scale=F)
dataP3$yearS <- as.numeric(dataP3$yearS)


formP3 <- LJI ~ h_polcon3_lag1 + loggdpS + common + yearS + 
				dpi_yio_lag2S + pwt_gsg_lag1S +
				fdiS + conflict2 + (1|cname) 	
res.hlmP3 <- lmer(formP3,dataP3,REML=FALSE)
res.feP3 <- lm(LJI ~ h_polcon3_lag1 + loggdpS + common + yearS + 
				dpi_yio_lag2S + pwt_gsg_lag1S +
				fdiS + conflict2 + cname ,dataP3)

texreg(list(res.hlmP, res.feP, res.hlmP3, res.feP3),
		stars=c(0.001,0.01,0.05),
		digits=2,booktabs=TRUE,
		dcolumn=TRUE,caption.above=TRUE,
		scalebox=1,
		custom.model.names=c("Polity (RE)","Polity (FE)","H/T/W (RE)","H/T/W (FE)"),label="fullautocracy",
		omit.coef="cname",include.aicc=TRUE
	)
options(digits=7)
AICc(res.hlmP)	
AICc(res.feP)	
AICc(res.hlmP3)	
AICc(res.feP3)	
options(digits=2)


library(effects)

pdf("EJPR_RnR_PolityRE.pdf",height=4,width=4,family="Palatino")
plot(effect("h_polcon3_lag1", res.hlmP,
	confidence.level=0.95,rug=FALSE),grid=TRUE,
	xlab="Electoral competition",
	ylab="De facto independence",
	main="",rug=FALSE,ylim=c(0.18,0.3))
dev.off()

pdf("EJPR_RnR_PolityFE.pdf",height=4,width=4,family="Palatino")
plot(effect("h_polcon3_lag1", res.feP,
	confidence.level=0.95,rug=FALSE),grid=TRUE,
	xlab="Electoral competition",
	ylab="De facto independence",
	main="",rug=FALSE,ylim=c(0.18,0.3))
dev.off()

pdf("EJPR_RnR_HTWre.pdf",height=4,width=4,family="Palatino")
plot(effect("h_polcon3_lag1", res.hlmP3,
	confidence.level=0.95,rug=FALSE),grid=TRUE,
	xlab="Electoral competition",
	ylab="De facto independence",
	main="",rug=FALSE,ylim=c(0.24,0.38))
dev.off()

pdf("EJPR_RnR_HTWfe.pdf",height=4,width=4,family="Palatino")
plot(effect("h_polcon3_lag1", res.feP3,
	confidence.level=0.95,rug=FALSE),grid=TRUE,
	xlab="Electoral competition",
	ylab="De facto independence",
	main="",rug=FALSE,ylim=c(0.24,0.38))
dev.off()	


## Model averaging

library(MuMIn)
#h.form1 <- LJI ~ h_polcon3_lag1S + loggdpS + common + pwt_gsg_lag1S + fdiS + dpi_yio_lag2S + yearS
h.out1 <- lme( LJI ~ h_polcon3_lag1S + loggdpS + common + pwt_gsg_lag1S + fdiS + dpi_yio_lag2S + yearS + conflict2,random=~1|cname,data0,method="ML")
h.out1.dredge <- dredge(h.out1,trace=TRUE,rank="AICc",REML=FALSE)
h.out1.avg <- model.avg(get.models(h.out1.dredge,subset=TRUE))


# Five year averages of pol. competition:

data0$polcon_lag2 <- lagpanel(data0$h_polcon3_lag1,data0$cname,data0$year.x,2)
data0$polcon_lag3 <- lagpanel(data0$h_polcon3_lag1,data0$cname,data0$year.x,3)
data0$polcon_lag4 <- lagpanel(data0$h_polcon3_lag1,data0$cname,data0$year.x,4)
data0$polcon_lag5 <- lagpanel(data0$h_polcon3_lag1,data0$cname,data0$year.x,5)

xx <- cbind(data0$h_polcon3_lag1,data0$polcon_lag2,data0$polcon_lag3,data0$polcon_lag4,data0$polcon_lag5)
data0$opp_mean5 <- rowMeans(xx,na.rm=T)

data0$opp_mean5.c <- scale(data0$opp_mean5,scale=F)
data0$opp_mean5.c <- as.numeric(data0$opp_mean5.c)

formAVG <- LJI ~ opp_mean5.c + loggdpS + common + yearS + dpi_yio_lag2S + pwt_gsg_lag1S +
				  fdiS + conflict2 + (1|cname)	
				
res.hlm.05 <- lmer(formAVG,data0,REML=FALSE)
res.fe.05 <- lm(LJI ~ opp_mean5.c + loggdpS + common + yearS + dpi_yio_lag2S + pwt_gsg_lag1S +
				  fdiS + conflict2 + cname,
				data0)

chdata$polcon_lag2 <- lagpanel(chdata$h_polcon3_lag1,chdata$cname,chdata$year.x,2)
chdata$polcon_lag3 <- lagpanel(chdata$h_polcon3_lag1,chdata$cname,chdata$year.x,3)
chdata$polcon_lag4 <- lagpanel(chdata$h_polcon3_lag1,chdata$cname,chdata$year.x,4)
chdata$polcon_lag5 <- lagpanel(chdata$h_polcon3_lag1,chdata$cname,chdata$year.x,5)

xx <- cbind(chdata$h_polcon3_lag1,chdata$polcon_lag2,chdata$polcon_lag3,chdata$polcon_lag4,chdata$polcon_lag5)
chdata$opp_mean5 <- rowMeans(xx,na.rm=T)

chdata$opp_mean5.c <- scale(chdata$opp_mean5,scale=F)
chdata$opp_mean5.c <- as.numeric(chdata$opp_mean5.c)


res.hlm.ch.05 <- lmer(LJI ~ opp_mean5.c + loggdpS + common + yearS + dpi_yio_lag2S +
				 (1|cname) ,chdata,REML=FALSE)
res.fe.ch.05 <- lm(LJI ~ opp_mean5.c + loggdpS + common + yearS + dpi_yio_lag2S +
				cname,chdata)


rdata$polcon_lag2 <- lagpanel(rdata$h_polcon3_lag1,rdata$cname,rdata$year.x,2)
rdata$polcon_lag3 <- lagpanel(rdata$h_polcon3_lag1,rdata$cname,rdata$year.x,3)
rdata$polcon_lag4 <- lagpanel(rdata$h_polcon3_lag1,rdata$cname,rdata$year.x,4)
rdata$polcon_lag5 <- lagpanel(rdata$h_polcon3_lag1,rdata$cname,rdata$year.x,5)

xx <- cbind(rdata$h_polcon3_lag1,rdata$polcon_lag2,rdata$polcon_lag3,rdata$polcon_lag4,rdata$polcon_lag5)
rdata$opp_mean5 <- rowMeans(xx,na.rm=T)

rdata$opp_mean5.c <- scale(rdata$opp_mean5,scale=F)
rdata$opp_mean5.c <- as.numeric(rdata$opp_mean5.c)

res.hlm.r.05 <- lmer(LJI ~ opp_mean5.c + loggdpS + common + yearS +
				 (1|cname) ,rdata,REML=FALSE)
res.fe.r.05 <- lm(LJI ~ opp_mean5.c + loggdpS + common + yearS  +
				cname,rdata)
				
mtable12 <- mtable("Model 1d" = res.hlm.05, "Model 2d" = res.fe.05, 
			"Model 3d" = res.hlm.ch.05,
			"Model 4d" = res.fe.ch.05, "Model 5d" = res.hlm.r.05, "Model 6d" = res.fe.r.05,
			summary.stats=c("AIC","N"))
			
mtable13 <- (mtable12 <- relabel(mtable12,
	"(Intercept)"="Intercept",
	"h_polcon3_lag1S" = "Political competition",
	"loggdpS" = "log(GDP/capita)",
	"common" = "Common law heritage",
	"yearS" = "Year",
	"pwt_gsg_lag1S" = "Government share of GDP",
	"roi_lag1S" = "Bureaucratic quality",
	"Ranef - cname" = "Random effect: country",
	"Ranef - year" = "Random effect: year",
	"Ranef - Residual" = "Random effect: residual",
	"wdi_gdpgr_lag1S" = "Economic growth",
	"conflict2" = "Conflict",
	"fdiS" = "Foreign direct investment",
	"dpi_yio_lag2S" = "Years in office"
)
)
mtable13
toLatex(mtable13,bottomrule="\\bottomrule \\bottomrule",toprule="\\toprule \\toprule")
options(digits=7)
AICc(res.hlm.05)
AICc(res.fe.05)
AICc(res.hlm.ch.05)
AICc(res.fe.ch.05)
AICc(res.hlm.r.05)
AICc(res.fe.r.05)
options(digits=2)


# BY DECADE


model2 <- LJI ~ h_polcon3_lag1S + common + loggdpS + yearS + (1|cname)
chdata1960 <- subset(rdata,year.x < 1971)			
summary(res.hlm.ch60 <- lmer(model2,chdata1960,REML=FALSE))	
chdata1970 <- subset(rdata,year.x > 1970 & year.x < 1981)			
summary(res.hlm.ch70 <- lmer(model2,chdata1970,REML=FALSE))	
chdata1980 <- subset(rdata,year.x > 1980 & year.x < 1991)			
summary(res.hlm.ch80 <- lmer(model2,chdata1980,REML=FALSE))	
chdata1990 <- subset(rdata,year.x > 1990 & year.x < 2001)			
summary(res.hlm.ch90 <- lmer(model2,chdata1990,REML=FALSE))	
data0_1980 <- subset(data0,year.x > 1980 & year.x < 1991)			
summary(res.hlm.0_80 <- lmer(form1,data0_1980,REML=FALSE))					   
data0_1990 <- subset(data0,year.x > 1990 & year.x < 2001)			
summary(res.hlm.0_90 <- lmer(form1,data0_1990,REML=FALSE))

mtable12 <- mtable("Model 5e" = res.hlm.ch60, "Model 5f" = res.hlm.ch70, 
			"Model 5g" = res.hlm.ch80,
			"Model 5h" = res.hlm.ch90, "Model 1e" = res.hlm.0_80 , "Model 1f" = res.hlm.0_90 ,
			summary.stats=c("AIC","N"))
			
mtable13 <- (mtable12 <- relabel(mtable12,
	"(Intercept)"="Intercept",
	"h_polcon3_lag1S" = "Political competition",
	"loggdpS" = "log(GDP/capita)",
	"common" = "Common law heritage",
	"yearS" = "Year",
	"pwt_gsg_lag1S" = "Government share of GDP",
	"roi_lag1S" = "Bureaucratic quality",
	"Ranef - cname" = "Random effect: country",
	"Ranef - year" = "Random effect: year",
	"Ranef - Residual" = "Random effect: residual",
	"wdi_gdpgr_lag1S" = "Economic growth",
	"conflict2" = "Conflict",
	"fdiS" = "Foreign direct investment",
	"dpi_yio_lag2S" = "Years in office"
)
)
mtable13
toLatex(mtable13,bottomrule="\\bottomrule \\bottomrule",toprule="\\toprule \\toprule")
options(digits=7)
AICc(res.hlm.ch60)
AICc(res.hlm.ch70)
AICc(res.hlm.ch80)
AICc(res.hlm.ch90)
AICc(res.hlm.0_80)
AICc(res.hlm.0_90 )
options(digits=2)


## Multiple imputation 

form1 <- LJI ~ gle_gdp_lag1 + h_polcon3_lag1 + common + wdi_gdpgr_lag1 + 
	roi_lag1 + pwt_gsg_lag1 + dpi_yio_lag2 + wdi_fdi_lag1 + conflict2 +
	wdi_gnipc_lag1 + cname + year.x + chga_demo + fh_democ
adata <- extractdata(form1,data2,na.rm=F)

require(Amelia)
set.seed(3)
imput.bounds <- matrix(c(
					3,         #vars
					0,         #mins
					1),     #maxs
					nrow=1,ncol=3)
a.out <- amelia(adata,m=15,ts="year.x",cs="cname",
			idvars=c("chga_demo"),
			ords=c("conflict2"),
			bounds=imput.bounds,
			noms=c("fh_democ"),			
			logistic=c("h_polcon3_lag1"),
			log=c("gle_gdp_lag1","wdi_gnipc_lag1"),
			max.resample=100)

# some diagnostics
# par(mar=c(5,5,4,2))
# plot(a.out,which.var=6,cex.lab=2,cex.main=1.5,cex.axis=1.75,
	# main="",xlab="13% missing",col=c("gray","black"),lwd=2,bty="n")
# plot(a.out,which.var=7,cex.lab=2,cex.main=1.5,cex.axis=1.75,
	# main="",xlab="10% missing",col=c("gray","black"),lwd=2,bty="n")
# plot(a.out,which.var=8,cex.lab=2,cex.main=1.5,cex.axis=1.75,
	# main="",xlab="36% missing",col=c("gray","black"),lwd=2,bty="n")
# plot(a.out,which.var=10,cex.lab=2,cex.main=1.5,cex.axis=1.75,
	# main="",xlab="9% missing",col=c("gray","black"),lwd=2,bty="n")
# plot(a.out,which.var=9,cex.lab=2,cex.main=1.5,cex.axis=1.75,
	# main="",xlab="41% missing",col=c("gray","black"),lwd=2,bty="n")
# plot(a.out,which.var=11,cex.lab=2,cex.main=1.5,cex.axis=1.75,
	# main="",xlab="31% missing",col=c("gray","black"),lwd=2,bty="n")
# overimpute(a.out,var="gle_gdp_lag1",bty="n")
# overimpute(a.out,var="roi_lag1",bty="n")
# overimpute(a.out,var="pwt_openk",bty="n")
# overimpute(a.out,var="dpi_yio_lag2",bty="n")
# missmap(a.out)

library(Zelig)

z.out2 <- zelig(LJI ~ h_polcon3_lag1 + log(gle_gdp_lag1) + common + year.x + dpi_yio_lag2 +
				pwt_gsg_lag1 + I(wdi_fdi_lag1/wdi_gnipc_lag1) + conflict2 +
				cname,
		data=a.out,model="ls")

z.out1 <- zelig(LJI ~ h_polcon3_lag1 + log(gle_gdp_lag1) + common + year.x + dpi_yio_lag2 +
				pwt_gsg_lag1 + I(wdi_fdi_lag1/wdi_gnipc_lag1) + conflict2 + tag(1|cname),
				data=a.out,model="ls.mixed",REML=FALSE)

z.out1.aicc <- ( AICc(z.out1$imp1)+ AICc(z.out1$imp2)+ AICc(z.out1$imp3)+ AICc(z.out1$imp4)+ AICc(z.out1$imp5)+
				 AICc(z.out1$imp6)+ AICc(z.out1$imp7)+ AICc(z.out1$imp8)+ AICc(z.out1$imp9)+ AICc(z.out1$imp10)+
				  AICc(z.out1$imp11)+ AICc(z.out1$imp12)+ AICc(z.out1$imp13)+ AICc(z.out1$imp14)+ AICc(z.out1$imp15))/15
				
z.out2.aicc <- ( AICc(z.out2$imp1)+ AICc(z.out2$imp2)+ AICc(z.out2$imp3)+ AICc(z.out2$imp4)+ AICc(z.out2$imp5)+
				 AICc(z.out2$imp6)+ AICc(z.out2$imp7)+ AICc(z.out2$imp8)+ AICc(z.out2$imp9)+ AICc(z.out2$imp10)+
				  AICc(z.out2$imp11)+ AICc(z.out2$imp12)+ AICc(z.out2$imp13)+ AICc(z.out2$imp14)+ AICc(z.out2$imp15))/15
				
